exceptiontools.ClefError
========================

.. inheritance-diagram:: abjad.tools.exceptiontools.ClefError.ClefError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ClefError.ClefError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
